Discover Packages
github.com/canonical/iot-management
domain
package
Version:
v0.0.0-...-88bcfc7
Opens a new window with list of versions in this module.
Published: Jan 31, 2022
License: AGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Organization struct {
OrganizationID string `json:"orgid"`
Name string `json:"name"`
}
Organization holds details of the organization
type OrganizationCreate struct {
Name string `json:"name"`
Country string `json:"country"`
}
OrganizationCreate holds details of the organization creation request
type User struct {
ID int64 `json:"id"`
Username string `json:"username"`
Name string `json:"name"`
Email string `json:"email"`
Role int `json:"role"`
}
User holds user personal, authentication and authorization info
Source Files
¶
Click to show internal directories.
Click to hide internal directories.